import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import math


def plot_categorical(df, size_inches=(5, 7), num_cols=None):
    """Plot counts of categorical features
    Args:
        df (dataframe): dataframe containing data to be ploted
        size_inches (tuple): plot size in inches
        num_cols: number of columns in plot
    Returns:
        fig, ax: plot
    """
    num_features = df.select_dtypes(include=['O']).shape[1]
    num_rows = math.ceil(num_features / num_cols)
    fig, ax = plt.subplots()
    fig.set_size_inches(size_inches)
    for i, column in enumerate(df.select_dtypes(include=['O'])):
        plt.subplot(num_rows, num_cols, i + 1)
        df[column].value_counts().plot.barh()
        plt.title(column)
    return fig, ax


def plot_numerical(df, size_inches=(15, 20), num_cols=None, target_col=None):
    """Plot histograms of categorical features
    Args:
        df (dataframe): dataframe containing data to be ploted
        size_inches (tuple): plot size in inches
        num_cols: number of columns in plot
    Returns:
        fig, ax: plot
    """
    num_features = df.select_dtypes(include=['float64']).shape[1]
    num_rows = math.ceil(num_features / num_cols)
    fig, ax = plt.subplots()
    fig.set_size_inches(size_inches)

    for i, column in enumerate(df.select_dtypes(include=['float64'])):
        plt.subplot(num_rows, num_cols, i + 1)
        if target_col == None:
            plt.hist(df[column], alpha=0.5)
        else:
            target_cats = df[target_col].unique()
            for target_cat in target_cats:
                plt.hist(df.loc[df[f'{target_col}'] == f'{target_cat}',
                                column], alpha=0.5, label=f'{target_cat}')
            plt.legend()
        plt.title(column)

    return fig, ax


def summary_report(df):
    print(df.shape)
    print(f'Number of missing values: {df.isnull().sum().sum()}')



from setuptools import setup
from setuptools import find_packages

LONG_DESCRIPTION = """
**edautils** is a Python package providing exploratory data analysis (EDA) helper functions. 
edautils is well suited for many different kinds of applications:
  - Visualizing distributions
  - Summarizing datasets 
"""

required = ['pandas>=0.25.2', 'numpy>=1.17.0', 'matplotlib>=3.0.0']

extras_required = dict()
extras_required['tests'] = ['pytest>=4.0.0', 'pytest-pep8']

setup(name='edautils',
      version='0.1.4',
      description='Exploratory data analysis (EDA) helper functions',
      long_description=LONG_DESCRIPTION,
      long_description_content_type='text/markdown',
      author='David Furrer',
      author_email='furrer.david1@gmail.com',
      url='https://github.com/davidfurrer/edautils',
      license='MIT',
      install_requires=required,
      extras_require=extras_required,
      packages=find_packages(exclude=('tests')),
      package_data={'edautils': ['data/*']})
